@@ -58,7 +58,7 @@ class Grafana:
             raise
         except httpx.ReadError as e:
             if 'BAD_CERTIFICATE' in str(e):
-                raise CertificateError('Try setting GRAFANA_CLIENT_CERT and …_KEY')
+                raise CertificateError('Try setting GRAFANA_CLIENT_CERT and GRAFANA_CLIENT_KEY')
             raise
         if r.status_code != 200:
             raise GrafanaError('no 200 on /api/health')
@@ -72,6 +72,7 @@ class Grafana:
         https://grafana.com/docs/grafana/latest/http_api/create-api-tokens-for-org/
         """
         if role not in self.ROLES:
+            self.log.debug('invalid role', name=name, role=role)
             raise ValueError('invalid role')
         response = self.client.post('/api/auth/keys', json={'name': name, 'role': role})
         response.raise_for_status()
@@ -86,7 +87,7 @@ class Grafana:
         uids = [sr['uid'] for sr in search_results if sr['type'] == 'dash-db']
         for uid in uids:
             d = self.client.get(f'/api/dashboards/uid/{uid}').json()['dashboard']
-            result.append(Dashboard(d))
+            result.append(Dashboard(d, base_url=self.client.base_url))
         return result
 
     def post_dashboard(self, dashboard_data):
