@@ -65,7 +65,7 @@ def dashboard_list(ctx):
     grafana: Grafana = ctx.obj
 
     for board in grafana.dashboards():
-        print(board.title)
+        print(f'{board.url}\t({board.title})')
 
 
 @dashboard.command()
