@@ -23,6 +23,11 @@ class JSONThing:
 
 
 class Dashboard(JSONThing):
+    def __init__(self, raw, base_url):
+        super().__init__(raw)
+        base = str(base_url).rstrip('/')
+        self.url = f'{base}/d/{self.uid}'
+
     def export(self, path):
         path = Path(path)
         path.write_text(json.dumps(self.raw))
