@@ -8,7 +8,7 @@ def configure_structlog_dev(log_level='WARNING'):
     import structlog
 
     if isinstance(log_level, str):
-        log_level = getattr(logging, log_level)
+        log_level = getattr(logging, log_level.upper())
     structlog.configure(
         processors=[
             structlog.processors.add_log_level,
